==> csp_editor-1.2.0.tar.gz: csp_editor/l10n/fr.js <==
OC.L10N.register(
    "csp_editor",
    {
    "CSP Editor" : "Éditeur CSP",
    "An app to edit Nextcloud's default CSP policy" : "Une application pour éditer la politique CSP par défaut de Nextcloud",
    "# Description\n\nThis app allows to edit Nextcloud's default CSP policy." : "# Description\n\nCette application permet d'éditer la politique CSP par défaut de Nextcloud.",
    "Allows to edit Nextcloud's default CSP policy." : "Permet d'éditer la politique CSP par défaut de Nextcloud.",
    "Note: Be extra careful with these settings, and add only what you need below." : "Note : Soyez super attentionné avec ces paramètres, et ajoutez que ce dont vous avez besoin ci-dessous.",
    "Allow eval script" : "Autoriser les scripts eval",
    "Allow scripts to use eval(). Very dangerous. Can be useful for development." : "Autorise les scripts à utiliser eval(). Très dangereux. Peut être utile pour le développement.",
    "You need to set \"debug\" => true in your config.php file to allow to use eval()." : "Vous devez définir \"debug\" => true dans votre fichier config.php pour autoriser les scripts eval.",
    "Allow inline styles" : "Autoriser les styles embarqués",
    "Allow inline styles to be used." : "Autorise les styles embarqués (inline) à être appliqués.",
    "Add a domain policy" : "Ajouter une politique pour un domaine",
    "Pick a policy type and enter a domain" : "Choisissez un type de politique et entrez un domaine",
    "domain.org" : "domaine.org",
    "Create" : "Créer",
    "Reset all" : "Tout réinitialiser",
    "No custom policy set" : "Aucune politique personnalisée définie",
    "Script" : "Script",
    "Style" : "Style",
    "Font" : "Font",
    "Image" : "Image",
    "Connect" : "Connect",
    "Media" : "Media",
    "Object" : "Object",
    "Child" : "Child",
    "Frame" : "Frame",
    "Frame Ancestor" : "Frame Ancestor",
    "WorkerSrc" : "WorkerSrc",
    "Form Action" : "Form Action",
    "Report To" : "Report To",
    "Error while saving custom CSP policy" : "Erreur lors de la sauvegarde de la politique CSP personnalisée"
},
"nplurals=2; plural=(n > 1);");

==> csp_editor-1.7.0.tar.gz: csp_editor/l10n/fr.js <==
OC.L10N.register(
    "csp_editor",
    {
    "CSP Editor" : "Éditeur CSP",
    "An app to edit Nextcloud's default CSP policy" : "Une application pour éditer la politique CSP par défaut de Nextcloud",
    "# Description\n\nThis app allows to edit Nextcloud's default CSP policy." : "# Description\n\nCette application permet d'éditer la politique CSP par défaut de Nextcloud.",
    "Allows to edit Nextcloud's default CSP policy." : "Permet d'éditer la politique CSP par défaut de Nextcloud.",
    "Note: Be extra careful with these settings, and add only what you need below." : "Note : Soyez super attentionné avec ces paramètres, et n'ajoutez que ce dont vous avez besoin ci-dessous.",
    "Allow eval script" : "Autoriser les scripts eval",
    "Allow scripts to use eval(). Very dangerous. Can be useful for development." : "Autorise les scripts à utiliser eval(). Très dangereux. Peut être utile pour le développement.",
    "You need to set \"debug\" => true in your config.php file to allow to use eval()." : "Vous devez définir \"debug\" => true dans votre fichier config.php pour autoriser les scripts eval.",
    "Allow inline styles" : "Autoriser les styles embarqués",
    "Allow inline styles to be used." : "Autorise les styles embarqués (inline) à être appliqués.",
    "Add a domain policy" : "Ajouter une politique pour un domaine",
    "Pick a policy type and enter a domain" : "Choisissez un type de politique et entrez un domaine",
    "domain.org" : "domaine.org",
    "Create" : "Créer",
    "Reset all" : "Tout réinitialiser",
    "No custom policy set" : "Aucune politique personnalisée définie",
    "Script" : "Script",
    "Style" : "Style",
    "Font" : "Font",
    "Image" : "Image",
    "Connect" : "Connect",
    "Media" : "Media",
    "Object" : "Object",
    "Child" : "Child",
    "Frame" : "Frame",
    "Frame Ancestor" : "Frame Ancestor",
    "WorkerSrc" : "WorkerSrc",
    "Form Action" : "Form Action",
    "Report To" : "Report To",
    "Error while saving custom CSP policy" : "Erreur lors de la sauvegarde de la politique CSP personnalisée"
},
"nplurals=2; plural=(n > 1);");
